@@ -144,9 +144,22 @@ impl Api {
         self.del(path).await
     }
 
+    pub(crate) async fn get_aws_location(
+        &self,
+        name: &v1::StateName,
+        region: v1::AwsRegion,
+    ) -> ApiResult<v1::StateLocationAws> {
+        let path = format!(
+            "/states/{name}/locations/aws/{region}",
+            name = name,
+            region = region
+        );
+        self.get(path).await
+    }
+
     pub(crate) async fn add_aws_location(
         &self,
-        name: v1::StateName,
+        name: &v1::StateName,
         region: v1::AwsRegion,
     ) -> ApiResult<v1::StateLocationAws> {
         let path = format!("/states/{name}/locations/aws", name = name);
@@ -154,16 +167,6 @@ impl Api {
         self.post(path, body).await
     }
 
-    pub(crate) async fn add_azure_location(
-        &self,
-        name: v1::StateName,
-        region: v1::AzureRegion,
-    ) -> ApiResult<v1::StateLocationAzure> {
-        let path = format!("/states/{name}/locations/azure", name = name);
-        let body = v1::CreateStateLocationAzureDto { region };
-        self.post(path, body).await
-    }
-
     pub(crate) async fn del_aws_location(
         &self,
         name: v1::StateName,
@@ -177,6 +180,29 @@ impl Api {
         self.del(path).await
     }
 
+    pub(crate) async fn get_azure_location(
+        &self,
+        name: &v1::StateName,
+        region: v1::AzureRegion,
+    ) -> ApiResult<v1::StateLocationAzure> {
+        let path = format!(
+            "/states/{name}/locations/azure/{region}",
+            name = name,
+            region = region
+        );
+        self.get(path).await
+    }
+
+    pub(crate) async fn add_azure_location(
+        &self,
+        name: &v1::StateName,
+        region: v1::AzureRegion,
+    ) -> ApiResult<v1::StateLocationAzure> {
+        let path = format!("/states/{name}/locations/azure", name = name);
+        let body = v1::CreateStateLocationAzureDto { region };
+        self.post(path, body).await
+    }
+
     pub(crate) async fn del_azure_location(
         &self,
         name: v1::StateName,
